Resolution

Struct Resolution 

pub struct Resolution<M: ZeroModule<Algebra = MilnorAlgebra>> {
    lock: Mutex<()>,
    name: String,
    max_degree: i32,
    modules: OnceBiVec<Arc<FreeModule<MilnorAlgebra>>>,
    zero_module: Arc<FreeModule<MilnorAlgebra>>,
    differentials: OnceBiVec<Arc<FreeModuleHomomorphism<FreeModule<MilnorAlgebra>>>>,
    target: Arc<FiniteChainComplex<M>>,
    chain_maps: OnceBiVec<Arc<FreeModuleHomomorphism<M>>>,
    save_dir: SaveDirectory,
}
A resolution of S_2 using Nassau’s algorithm.

This aims to have an API similar to that of resolution::Resolution. From an API point of view, the main difference between the two is that this is a chain complex over MilnorAlgebra over SteenrodAlgebra.

Fields

lock: Mutex<()>name: Stringmax_degree: i32modules: OnceBiVec<Arc<FreeModule<MilnorAlgebra>>>zero_module: Arc<FreeModule<MilnorAlgebra>>differentials: OnceBiVec<Arc<FreeModuleHomomorphism<FreeModule<MilnorAlgebra>>>>target: Arc<FiniteChainComplex<M>>chain_maps: OnceBiVec<Arc<FreeModuleHomomorphism<M>>>save_dir: SaveDirectory

Implementations

Source

impl<M: ZeroModule<Algebra = MilnorAlgebra>> Resolution<M>

pub fn name(&self) -> &str

pub fn set_name(&mut self, name: String)

pub fn new(module: Arc<M>) -> Self

pub fn new_with_save( module: Arc<M>, save_dir: impl Into<SaveDirectory>, ) -> Result<Self>

fn add_generators(&self, b: Bidegree, num_new_gens: usize)

fn extend_through_degree(&self, max_s: i32)

This function prepares the Resolution object to perform computations up to the specified s degree. It does not perform any computations by itself. It simply lengthens the OnceVecs modules, chain_maps, etc. to the right length.

fn write_qi( f: &mut Option<impl Write>, scratch: &mut FpVector, signature: &[PPartEntry], next_mask: &[usize], full_matrix: &Matrix, masked_matrix: &AugmentedMatrix<2>, ) -> Result<()>

fn write_differential( &self, b: Bidegree, num_new_gens: usize, target_dim: usize, ) -> Result<()>

fn step_resolution_with_subalgebra( &self, b: Bidegree, subalgebra: MilnorSubalgebra, ) -> Result<()>

fn step0(&self, t: i32)

Step resolution for s = 0

fn step1(&self, t: i32) -> Result<()>

Step resolution for s = 1

fn step_resolution_with_result(&self, b: Bidegree) -> Result<()>

fn step_resolution(&self, b: Bidegree)

pub fn compute_through_stem(&self, max: Bidegree)

This function resolves up till a fixed stem instead of a fixed t.