SenderData

Struct SenderData 

struct SenderData {
    b: Bidegree,
    new: bool,
    retry: bool,
    sender: Sender<Self>,
}
In MuResolution::compute_through_stem and MuResolution::compute_through_bidegree, we pass this struct around to inform the supervisor what bidegrees have been computed. We use an explicit struct instead of a tuple to avoid an infinite type problem.

Fields

b: Bidegreenew: bool

Whether this bidegree was newly calculated or have already been calculated.

retry: bool

Whether this job should be retried due to priority inversion avoidance.

sender: Sender<Self>

The sender object used to send the SenderData. We put this in the struct and pass it around the mpsc, so that when all senders are dropped, we know the computation has completed. Compared to keeping track of calculations manually, this has the advantage of behaving correctly when a thread panicking.

Implementations

Source

impl SenderData

fn send(b: Bidegree, new: bool, sender: Sender<Self>)

fn send_retry(b: Bidegree, sender: Sender<Self>)