ChecksumWriter

Struct ChecksumWriter 

pub struct ChecksumWriter<T: Write> {
    writer: T,
    path: PathBuf,
    adler: Adler32,
}
In addition to checking the checksum, we also keep track of which files are open, and we delete the open files if the program is terminated halfway.

Fields

writer: Tpath: PathBufadler: Adler32

Implementations

Source

impl<T: Write> ChecksumWriter<T>

pub fn new(path: PathBuf, writer: T) -> Self