get_unit

Function get_unit 

pub fn get_unit(
    resolution: Arc<QueryModuleResolution>,
) -> Result<(bool, Arc<QueryModuleResolution>)>
Given a resolution, return a resolution of the unit.

The return value comes with a boolean indicating whether the original resolution was already a resolution of the unit. If the boolean is true, then the original resolution is returned.