load_module_json

Function load_module_json 

pub fn load_module_json(name: &str) -> Result<Value>
Load a module specification from a JSON file.

Given the name of a module file (without the .json extension), find a json file with this name, and return the parsed json object. The search path for this json file is described here.