query_module_only

Function query_module_only 

pub fn query_module_only(
    prompt: &str,
    algebra: Option<AlgebraType>,
    load_quasi_inverse: bool,
) -> Result<QueryModuleResolution>
Query the user for a module and its save directory. See here for details on the propmt format.

Arguments

  • prompt: The prompt used to query the user for the module. This is "Module" when invoked through query_module, but the user may want to use something more specific, e.g. "Source module".
  • algebra: The Steenrod algebra basis allowed. Some applications only support using one of the two basis, and specifying this parameter forbids the user from specifying the other basis.
  • load_quasi_inverse: Whether or not the quasi-inverses of the resolution should be stored. Note that if there is a save directory, then quasi-inverses will never be stored in memory; they must be accessed via apply_quasi_inverse.

Returns

A QueryModuleResolution. Note that this type depends on whether the nassau feature is enabled.