pub fn construct<T, E>(
module_spec: T,
save_dir: impl Into<SaveDirectory>,
) -> Result<QueryModuleResolution>Expand description
This constructs a resolution resolving a module according to the specifications
Arguments
module_spec: A specification for the module. This is any object that implementsTryInto<Config>(with appropriate error bounds). In practice, we can supply- A
Configobject itself (json, algebra): The first argument is aserde_json::Valuethat specifies the module; the second argument is either a string ("milnor"or"adem") or analgebra::AlgebraTypeobject.(module_name, algebra): The first argument is the name of the module and the second is as above. Modules are searched in the current directory,$CWD/steenrod_modulesandext/steenrod_modules. The modules can be shifted by appending e.g.S_2[2].module_spec, a single&strof the formmodule_name@algebra, wheremodule_nameandalgebraare as above.
- A
save_file: The save file for the module. If it points to an invalid save file, an error is returned.
This dispatches to either construct_nassau or construct_standard depending on whether
the nassau feature is enabled.